pycocoa.octypes.c_struct_t

Package pycocoa :: Module octypes :: Class c_struct_t |
[frames] | no frames]

# Class c_struct_t

       object --+
                |
        ??._CData --+
                    |
    _ctypes.Structure --+
                        |
                       c_struct_t

Known Subclasses:
  - CFRange_t
  - , NSPoint_t
  - , NSRect_t
  - , NSSize_t
  - , NSRange_t
  - , printers.PMRect_t
  - , objc_method_description_t
  - , objc_property_attribute_t
  - , objc_super_t
  - , printers.PMResolution_t

Base type to pretty-print ctypes `Structures`.

Instance Methods
__repr__(self) repr(x) |
__str__(self) str(x) |
Inherited from `_ctypes.Structure`: `__init__`, `__new__` Inherited from `_CData`: `__ctypes_from_outparam__`, `__hash__`, `__reduce__`, `__setstate__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`

Method Details

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)

### __str__(self) (Informal representation operator) |
str(x) Overrides: object.__str__ (inherited documentation)